# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.historic_activity_instance_api import HistoricActivityInstanceApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestHistoricActivityInstanceApi(unittest.TestCase):
    """HistoricActivityInstanceApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.historic_activity_instance_api.HistoricActivityInstanceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_historic_activity_instance(self):
        """Test case for get_historic_activity_instance

        Get  # noqa: E501
        """
        pass

    def test_get_historic_activity_instances(self):
        """Test case for get_historic_activity_instances

        Get List  # noqa: E501
        """
        pass

    def test_get_historic_activity_instances_count(self):
        """Test case for get_historic_activity_instances_count

        Get List Count  # noqa: E501
        """
        pass

    def test_query_historic_activity_instances(self):
        """Test case for query_historic_activity_instances

        Get List (POST)  # noqa: E501
        """
        pass

    def test_query_historic_activity_instances_count(self):
        """Test case for query_historic_activity_instances_count

        Get List Count (POST)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class VariableQueryParameterDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'operator': 'str',
        'value': 'object'
    }

    attribute_map = {
        'name': 'name',
        'operator': 'operator',
        'value': 'value'
    }

    def __init__(self, name=None, operator=None, value=None, local_vars_configuration=None):  # noqa: E501
        """VariableQueryParameterDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._operator = None
        self._value = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if operator is not None:
            self.operator = operator
        if value is not None:
            self.value = value

    @property
    def name(self):
        """Gets the name of this VariableQueryParameterDto.  # noqa: E501

        Variable name  # noqa: E501

        :return: The name of this VariableQueryParameterDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this VariableQueryParameterDto.

        Variable name  # noqa: E501

        :param name: The name of this VariableQueryParameterDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def operator(self):
        """Gets the operator of this VariableQueryParameterDto.  # noqa: E501

        Comparison operator to be used  # noqa: E501

        :return: The operator of this VariableQueryParameterDto.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this VariableQueryParameterDto.

        Comparison operator to be used  # noqa: E501

        :param operator: The operator of this VariableQueryParameterDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["eq", "neq", "gt", "gteq", "lt", "lteq", "like"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operator not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `operator` ({0}), must be one of {1}"  # noqa: E501
                .format(operator, allowed_values)
            )

        self._operator = operator

    @property
    def value(self):
        """Gets the value of this VariableQueryParameterDto.  # noqa: E501

        The variable value, could be of type boolean, string or number  # noqa: E501

        :return: The value of this VariableQueryParameterDto.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this VariableQueryParameterDto.

        The variable value, could be of type boolean, string or number  # noqa: E501

        :param value: The value of this VariableQueryParameterDto.  # noqa: E501
        :type: object
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VariableQueryParameterDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VariableQueryParameterDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class LockedExternalTaskDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'activity_id': 'str',
        'activity_instance_id': 'str',
        'error_message': 'str',
        'error_details': 'str',
        'execution_id': 'str',
        'id': 'str',
        'lock_expiration_time': 'datetime',
        'process_definition_id': 'str',
        'process_definition_key': 'str',
        'process_definition_version_tag': 'str',
        'process_instance_id': 'str',
        'tenant_id': 'str',
        'retries': 'int',
        'suspended': 'bool',
        'worker_id': 'str',
        'priority': 'int',
        'topic_name': 'str',
        'business_key': 'str',
        'variables': 'dict(str, VariableValueDto)'
    }

    attribute_map = {
        'activity_id': 'activityId',
        'activity_instance_id': 'activityInstanceId',
        'error_message': 'errorMessage',
        'error_details': 'errorDetails',
        'execution_id': 'executionId',
        'id': 'id',
        'lock_expiration_time': 'lockExpirationTime',
        'process_definition_id': 'processDefinitionId',
        'process_definition_key': 'processDefinitionKey',
        'process_definition_version_tag': 'processDefinitionVersionTag',
        'process_instance_id': 'processInstanceId',
        'tenant_id': 'tenantId',
        'retries': 'retries',
        'suspended': 'suspended',
        'worker_id': 'workerId',
        'priority': 'priority',
        'topic_name': 'topicName',
        'business_key': 'businessKey',
        'variables': 'variables'
    }

    def __init__(self, activity_id=None, activity_instance_id=None, error_message=None, error_details=None, execution_id=None, id=None, lock_expiration_time=None, process_definition_id=None, process_definition_key=None, process_definition_version_tag=None, process_instance_id=None, tenant_id=None, retries=None, suspended=None, worker_id=None, priority=None, topic_name=None, business_key=None, variables=None, local_vars_configuration=None):  # noqa: E501
        """LockedExternalTaskDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._activity_id = None
        self._activity_instance_id = None
        self._error_message = None
        self._error_details = None
        self._execution_id = None
        self._id = None
        self._lock_expiration_time = None
        self._process_definition_id = None
        self._process_definition_key = None
        self._process_definition_version_tag = None
        self._process_instance_id = None
        self._tenant_id = None
        self._retries = None
        self._suspended = None
        self._worker_id = None
        self._priority = None
        self._topic_name = None
        self._business_key = None
        self._variables = None
        self.discriminator = None

        if activity_id is not None:
            self.activity_id = activity_id
        if activity_instance_id is not None:
            self.activity_instance_id = activity_instance_id
        if error_message is not None:
            self.error_message = error_message
        if error_details is not None:
            self.error_details = error_details
        if execution_id is not None:
            self.execution_id = execution_id
        if id is not None:
            self.id = id
        self.lock_expiration_time = lock_expiration_time
        if process_definition_id is not None:
            self.process_definition_id = process_definition_id
        if process_definition_key is not None:
            self.process_definition_key = process_definition_key
        if process_definition_version_tag is not None:
            self.process_definition_version_tag = process_definition_version_tag
        if process_instance_id is not None:
            self.process_instance_id = process_instance_id
        if tenant_id is not None:
            self.tenant_id = tenant_id
        self.retries = retries
        self.suspended = suspended
        if worker_id is not None:
            self.worker_id = worker_id
        self.priority = priority
        if topic_name is not None:
            self.topic_name = topic_name
        if business_key is not None:
            self.business_key = business_key
        if variables is not None:
            self.variables = variables

    @property
    def activity_id(self):
        """Gets the activity_id of this LockedExternalTaskDto.  # noqa: E501

        The id of the activity that this external task belongs to.  # noqa: E501

        :return: The activity_id of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_id

    @activity_id.setter
    def activity_id(self, activity_id):
        """Sets the activity_id of this LockedExternalTaskDto.

        The id of the activity that this external task belongs to.  # noqa: E501

        :param activity_id: The activity_id of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._activity_id = activity_id

    @property
    def activity_instance_id(self):
        """Gets the activity_instance_id of this LockedExternalTaskDto.  # noqa: E501

        The id of the activity instance that the external task belongs to.  # noqa: E501

        :return: The activity_instance_id of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_instance_id

    @activity_instance_id.setter
    def activity_instance_id(self, activity_instance_id):
        """Sets the activity_instance_id of this LockedExternalTaskDto.

        The id of the activity instance that the external task belongs to.  # noqa: E501

        :param activity_instance_id: The activity_instance_id of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._activity_instance_id = activity_instance_id

    @property
    def error_message(self):
        """Gets the error_message of this LockedExternalTaskDto.  # noqa: E501

        The full error message submitted with the latest reported failure executing this task;`null` if no failure was reported previously or if no error message was submitted  # noqa: E501

        :return: The error_message of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """Sets the error_message of this LockedExternalTaskDto.

        The full error message submitted with the latest reported failure executing this task;`null` if no failure was reported previously or if no error message was submitted  # noqa: E501

        :param error_message: The error_message of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._error_message = error_message

    @property
    def error_details(self):
        """Gets the error_details of this LockedExternalTaskDto.  # noqa: E501

        The error details submitted with the latest reported failure executing this task.`null` if no failure was reported previously or if no error details was submitted  # noqa: E501

        :return: The error_details of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._error_details

    @error_details.setter
    def error_details(self, error_details):
        """Sets the error_details of this LockedExternalTaskDto.

        The error details submitted with the latest reported failure executing this task.`null` if no failure was reported previously or if no error details was submitted  # noqa: E501

        :param error_details: The error_details of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._error_details = error_details

    @property
    def execution_id(self):
        """Gets the execution_id of this LockedExternalTaskDto.  # noqa: E501

        The id of the execution that the external task belongs to.  # noqa: E501

        :return: The execution_id of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this LockedExternalTaskDto.

        The id of the execution that the external task belongs to.  # noqa: E501

        :param execution_id: The execution_id of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._execution_id = execution_id

    @property
    def id(self):
        """Gets the id of this LockedExternalTaskDto.  # noqa: E501

        The id of the external task.  # noqa: E501

        :return: The id of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LockedExternalTaskDto.

        The id of the external task.  # noqa: E501

        :param id: The id of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def lock_expiration_time(self):
        """Gets the lock_expiration_time of this LockedExternalTaskDto.  # noqa: E501

        The date that the task's most recent lock expires or has expired.  # noqa: E501

        :return: The lock_expiration_time of this LockedExternalTaskDto.  # noqa: E501
        :rtype: datetime
        """
        return self._lock_expiration_time

    @lock_expiration_time.setter
    def lock_expiration_time(self, lock_expiration_time):
        """Sets the lock_expiration_time of this LockedExternalTaskDto.

        The date that the task's most recent lock expires or has expired.  # noqa: E501

        :param lock_expiration_time: The lock_expiration_time of this LockedExternalTaskDto.  # noqa: E501
        :type: datetime
        """

        self._lock_expiration_time = lock_expiration_time

    @property
    def process_definition_id(self):
        """Gets the process_definition_id of this LockedExternalTaskDto.  # noqa: E501

        The id of the process definition the external task is defined in.  # noqa: E501

        :return: The process_definition_id of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_id

    @process_definition_id.setter
    def process_definition_id(self, process_definition_id):
        """Sets the process_definition_id of this LockedExternalTaskDto.

        The id of the process definition the external task is defined in.  # noqa: E501

        :param process_definition_id: The process_definition_id of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._process_definition_id = process_definition_id

    @property
    def process_definition_key(self):
        """Gets the process_definition_key of this LockedExternalTaskDto.  # noqa: E501

        The key of the process definition the external task is defined in.  # noqa: E501

        :return: The process_definition_key of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_key

    @process_definition_key.setter
    def process_definition_key(self, process_definition_key):
        """Sets the process_definition_key of this LockedExternalTaskDto.

        The key of the process definition the external task is defined in.  # noqa: E501

        :param process_definition_key: The process_definition_key of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._process_definition_key = process_definition_key

    @property
    def process_definition_version_tag(self):
        """Gets the process_definition_version_tag of this LockedExternalTaskDto.  # noqa: E501

        The version tag of the process definition the external task is defined in.  # noqa: E501

        :return: The process_definition_version_tag of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_version_tag

    @process_definition_version_tag.setter
    def process_definition_version_tag(self, process_definition_version_tag):
        """Sets the process_definition_version_tag of this LockedExternalTaskDto.

        The version tag of the process definition the external task is defined in.  # noqa: E501

        :param process_definition_version_tag: The process_definition_version_tag of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._process_definition_version_tag = process_definition_version_tag

    @property
    def process_instance_id(self):
        """Gets the process_instance_id of this LockedExternalTaskDto.  # noqa: E501

        The id of the process instance the external task belongs to.  # noqa: E501

        :return: The process_instance_id of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._process_instance_id

    @process_instance_id.setter
    def process_instance_id(self, process_instance_id):
        """Sets the process_instance_id of this LockedExternalTaskDto.

        The id of the process instance the external task belongs to.  # noqa: E501

        :param process_instance_id: The process_instance_id of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._process_instance_id = process_instance_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this LockedExternalTaskDto.  # noqa: E501

        The id of the tenant the external task belongs to.  # noqa: E501

        :return: The tenant_id of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this LockedExternalTaskDto.

        The id of the tenant the external task belongs to.  # noqa: E501

        :param tenant_id: The tenant_id of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def retries(self):
        """Gets the retries of this LockedExternalTaskDto.  # noqa: E501

        The number of retries the task currently has left.  # noqa: E501

        :return: The retries of this LockedExternalTaskDto.  # noqa: E501
        :rtype: int
        """
        return self._retries

    @retries.setter
    def retries(self, retries):
        """Sets the retries of this LockedExternalTaskDto.

        The number of retries the task currently has left.  # noqa: E501

        :param retries: The retries of this LockedExternalTaskDto.  # noqa: E501
        :type: int
        """

        self._retries = retries

    @property
    def suspended(self):
        """Gets the suspended of this LockedExternalTaskDto.  # noqa: E501

        Whether the process instance the external task belongs to is suspended.  # noqa: E501

        :return: The suspended of this LockedExternalTaskDto.  # noqa: E501
        :rtype: bool
        """
        return self._suspended

    @suspended.setter
    def suspended(self, suspended):
        """Sets the suspended of this LockedExternalTaskDto.

        Whether the process instance the external task belongs to is suspended.  # noqa: E501

        :param suspended: The suspended of this LockedExternalTaskDto.  # noqa: E501
        :type: bool
        """

        self._suspended = suspended

    @property
    def worker_id(self):
        """Gets the worker_id of this LockedExternalTaskDto.  # noqa: E501

        The id of the worker that posesses or posessed the most recent lock.  # noqa: E501

        :return: The worker_id of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._worker_id

    @worker_id.setter
    def worker_id(self, worker_id):
        """Sets the worker_id of this LockedExternalTaskDto.

        The id of the worker that posesses or posessed the most recent lock.  # noqa: E501

        :param worker_id: The worker_id of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._worker_id = worker_id

    @property
    def priority(self):
        """Gets the priority of this LockedExternalTaskDto.  # noqa: E501

        The priority of the external task.  # noqa: E501

        :return: The priority of this LockedExternalTaskDto.  # noqa: E501
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this LockedExternalTaskDto.

        The priority of the external task.  # noqa: E501

        :param priority: The priority of this LockedExternalTaskDto.  # noqa: E501
        :type: int
        """

        self._priority = priority

    @property
    def topic_name(self):
        """Gets the topic_name of this LockedExternalTaskDto.  # noqa: E501

        The topic name of the external task.  # noqa: E501

        :return: The topic_name of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._topic_name

    @topic_name.setter
    def topic_name(self, topic_name):
        """Sets the topic_name of this LockedExternalTaskDto.

        The topic name of the external task.  # noqa: E501

        :param topic_name: The topic_name of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._topic_name = topic_name

    @property
    def business_key(self):
        """Gets the business_key of this LockedExternalTaskDto.  # noqa: E501

        The business key of the process instance the external task belongs to.  # noqa: E501

        :return: The business_key of this LockedExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._business_key

    @business_key.setter
    def business_key(self, business_key):
        """Sets the business_key of this LockedExternalTaskDto.

        The business key of the process instance the external task belongs to.  # noqa: E501

        :param business_key: The business_key of this LockedExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._business_key = business_key

    @property
    def variables(self):
        """Gets the variables of this LockedExternalTaskDto.  # noqa: E501

        A JSON object containing a property for each of the requested variables. The key is the variable name, the value is a JSON object of serialized variable values with the following properties:  # noqa: E501

        :return: The variables of this LockedExternalTaskDto.  # noqa: E501
        :rtype: dict(str, VariableValueDto)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """Sets the variables of this LockedExternalTaskDto.

        A JSON object containing a property for each of the requested variables. The key is the variable name, the value is a JSON object of serialized variable values with the following properties:  # noqa: E501

        :param variables: The variables of this LockedExternalTaskDto.  # noqa: E501
        :type: dict(str, VariableValueDto)
        """

        self._variables = variables

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LockedExternalTaskDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LockedExternalTaskDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class DurationReportResultDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'period': 'int',
        'period_unit': 'str',
        'minimum': 'int',
        'maximum': 'int',
        'average': 'int'
    }

    attribute_map = {
        'period': 'period',
        'period_unit': 'periodUnit',
        'minimum': 'minimum',
        'maximum': 'maximum',
        'average': 'average'
    }

    def __init__(self, period=None, period_unit=None, minimum=None, maximum=None, average=None, local_vars_configuration=None):  # noqa: E501
        """DurationReportResultDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._period = None
        self._period_unit = None
        self._minimum = None
        self._maximum = None
        self._average = None
        self.discriminator = None

        if period is not None:
            self.period = period
        if period_unit is not None:
            self.period_unit = period_unit
        if minimum is not None:
            self.minimum = minimum
        if maximum is not None:
            self.maximum = maximum
        if average is not None:
            self.average = average

    @property
    def period(self):
        """Gets the period of this DurationReportResultDto.  # noqa: E501

        Specifies a timespan within a year. **Note:** The period must be interpreted in conjunction with the returned `periodUnit`.  # noqa: E501

        :return: The period of this DurationReportResultDto.  # noqa: E501
        :rtype: int
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this DurationReportResultDto.

        Specifies a timespan within a year. **Note:** The period must be interpreted in conjunction with the returned `periodUnit`.  # noqa: E501

        :param period: The period of this DurationReportResultDto.  # noqa: E501
        :type: int
        """

        self._period = period

    @property
    def period_unit(self):
        """Gets the period_unit of this DurationReportResultDto.  # noqa: E501

        The unit of the given period. Possible values are `MONTH` and `QUARTER`.  # noqa: E501

        :return: The period_unit of this DurationReportResultDto.  # noqa: E501
        :rtype: str
        """
        return self._period_unit

    @period_unit.setter
    def period_unit(self, period_unit):
        """Sets the period_unit of this DurationReportResultDto.

        The unit of the given period. Possible values are `MONTH` and `QUARTER`.  # noqa: E501

        :param period_unit: The period_unit of this DurationReportResultDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["MONTH", "QUARTER"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and period_unit not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `period_unit` ({0}), must be one of {1}"  # noqa: E501
                .format(period_unit, allowed_values)
            )

        self._period_unit = period_unit

    @property
    def minimum(self):
        """Gets the minimum of this DurationReportResultDto.  # noqa: E501

        The smallest duration in milliseconds of all completed process instances which were started in the given period.  # noqa: E501

        :return: The minimum of this DurationReportResultDto.  # noqa: E501
        :rtype: int
        """
        return self._minimum

    @minimum.setter
    def minimum(self, minimum):
        """Sets the minimum of this DurationReportResultDto.

        The smallest duration in milliseconds of all completed process instances which were started in the given period.  # noqa: E501

        :param minimum: The minimum of this DurationReportResultDto.  # noqa: E501
        :type: int
        """

        self._minimum = minimum

    @property
    def maximum(self):
        """Gets the maximum of this DurationReportResultDto.  # noqa: E501

        The greatest duration in milliseconds of all completed process instances which were started in the given period.  # noqa: E501

        :return: The maximum of this DurationReportResultDto.  # noqa: E501
        :rtype: int
        """
        return self._maximum

    @maximum.setter
    def maximum(self, maximum):
        """Sets the maximum of this DurationReportResultDto.

        The greatest duration in milliseconds of all completed process instances which were started in the given period.  # noqa: E501

        :param maximum: The maximum of this DurationReportResultDto.  # noqa: E501
        :type: int
        """

        self._maximum = maximum

    @property
    def average(self):
        """Gets the average of this DurationReportResultDto.  # noqa: E501

        The average duration in milliseconds of all completed process instances which were started in the given period.  # noqa: E501

        :return: The average of this DurationReportResultDto.  # noqa: E501
        :rtype: int
        """
        return self._average

    @average.setter
    def average(self, average):
        """Sets the average of this DurationReportResultDto.

        The average duration in milliseconds of all completed process instances which were started in the given period.  # noqa: E501

        :param average: The average of this DurationReportResultDto.  # noqa: E501
        :type: int
        """

        self._average = average

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DurationReportResultDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DurationReportResultDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class DeleteProcessInstancesDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'process_instance_ids': 'list[str]',
        'delete_reason': 'str',
        'skip_custom_listeners': 'bool',
        'skip_subprocesses': 'bool',
        'process_instance_query': 'ProcessInstanceQueryDto',
        'historic_process_instance_query': 'HistoricProcessInstanceQueryDto'
    }

    attribute_map = {
        'process_instance_ids': 'processInstanceIds',
        'delete_reason': 'deleteReason',
        'skip_custom_listeners': 'skipCustomListeners',
        'skip_subprocesses': 'skipSubprocesses',
        'process_instance_query': 'processInstanceQuery',
        'historic_process_instance_query': 'historicProcessInstanceQuery'
    }

    def __init__(self, process_instance_ids=None, delete_reason=None, skip_custom_listeners=None, skip_subprocesses=None, process_instance_query=None, historic_process_instance_query=None, local_vars_configuration=None):  # noqa: E501
        """DeleteProcessInstancesDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._process_instance_ids = None
        self._delete_reason = None
        self._skip_custom_listeners = None
        self._skip_subprocesses = None
        self._process_instance_query = None
        self._historic_process_instance_query = None
        self.discriminator = None

        if process_instance_ids is not None:
            self.process_instance_ids = process_instance_ids
        if delete_reason is not None:
            self.delete_reason = delete_reason
        self.skip_custom_listeners = skip_custom_listeners
        self.skip_subprocesses = skip_subprocesses
        if process_instance_query is not None:
            self.process_instance_query = process_instance_query
        if historic_process_instance_query is not None:
            self.historic_process_instance_query = historic_process_instance_query

    @property
    def process_instance_ids(self):
        """Gets the process_instance_ids of this DeleteProcessInstancesDto.  # noqa: E501

        A list process instance ids to delete.  # noqa: E501

        :return: The process_instance_ids of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._process_instance_ids

    @process_instance_ids.setter
    def process_instance_ids(self, process_instance_ids):
        """Sets the process_instance_ids of this DeleteProcessInstancesDto.

        A list process instance ids to delete.  # noqa: E501

        :param process_instance_ids: The process_instance_ids of this DeleteProcessInstancesDto.  # noqa: E501
        :type: list[str]
        """

        self._process_instance_ids = process_instance_ids

    @property
    def delete_reason(self):
        """Gets the delete_reason of this DeleteProcessInstancesDto.  # noqa: E501

        A string with delete reason.  # noqa: E501

        :return: The delete_reason of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: str
        """
        return self._delete_reason

    @delete_reason.setter
    def delete_reason(self, delete_reason):
        """Sets the delete_reason of this DeleteProcessInstancesDto.

        A string with delete reason.  # noqa: E501

        :param delete_reason: The delete_reason of this DeleteProcessInstancesDto.  # noqa: E501
        :type: str
        """

        self._delete_reason = delete_reason

    @property
    def skip_custom_listeners(self):
        """Gets the skip_custom_listeners of this DeleteProcessInstancesDto.  # noqa: E501

        Skip execution listener invocation for activities that are started or ended as part of this request.  # noqa: E501

        :return: The skip_custom_listeners of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_custom_listeners

    @skip_custom_listeners.setter
    def skip_custom_listeners(self, skip_custom_listeners):
        """Sets the skip_custom_listeners of this DeleteProcessInstancesDto.

        Skip execution listener invocation for activities that are started or ended as part of this request.  # noqa: E501

        :param skip_custom_listeners: The skip_custom_listeners of this DeleteProcessInstancesDto.  # noqa: E501
        :type: bool
        """

        self._skip_custom_listeners = skip_custom_listeners

    @property
    def skip_subprocesses(self):
        """Gets the skip_subprocesses of this DeleteProcessInstancesDto.  # noqa: E501

        Skip deletion of the subprocesses related to deleted processes as part of this request.  # noqa: E501

        :return: The skip_subprocesses of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_subprocesses

    @skip_subprocesses.setter
    def skip_subprocesses(self, skip_subprocesses):
        """Sets the skip_subprocesses of this DeleteProcessInstancesDto.

        Skip deletion of the subprocesses related to deleted processes as part of this request.  # noqa: E501

        :param skip_subprocesses: The skip_subprocesses of this DeleteProcessInstancesDto.  # noqa: E501
        :type: bool
        """

        self._skip_subprocesses = skip_subprocesses

    @property
    def process_instance_query(self):
        """Gets the process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501


        :return: The process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: ProcessInstanceQueryDto
        """
        return self._process_instance_query

    @process_instance_query.setter
    def process_instance_query(self, process_instance_query):
        """Sets the process_instance_query of this DeleteProcessInstancesDto.


        :param process_instance_query: The process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501
        :type: ProcessInstanceQueryDto
        """

        self._process_instance_query = process_instance_query

    @property
    def historic_process_instance_query(self):
        """Gets the historic_process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501


        :return: The historic_process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: HistoricProcessInstanceQueryDto
        """
        return self._historic_process_instance_query

    @historic_process_instance_query.setter
    def historic_process_instance_query(self, historic_process_instance_query):
        """Sets the historic_process_instance_query of this DeleteProcessInstancesDto.


        :param historic_process_instance_query: The historic_process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501
        :type: HistoricProcessInstanceQueryDto
        """

        self._historic_process_instance_query = historic_process_instance_query

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteProcessInstancesDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeleteProcessInstancesDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class HistoricProcessInstanceDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'root_process_instance_id': 'str',
        'super_process_instance_id': 'str',
        'super_case_instance_id': 'str',
        'case_instance_id': 'str',
        'process_definition_name': 'str',
        'process_definition_key': 'str',
        'process_definition_version': 'int',
        'process_definition_id': 'str',
        'business_key': 'str',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'removal_time': 'datetime',
        'duration_in_millis': 'int',
        'start_user_id': 'str',
        'start_activity_id': 'str',
        'delete_reason': 'str',
        'tenant_id': 'str',
        'state': 'str'
    }

    attribute_map = {
        'id': 'id',
        'root_process_instance_id': 'rootProcessInstanceId',
        'super_process_instance_id': 'superProcessInstanceId',
        'super_case_instance_id': 'superCaseInstanceId',
        'case_instance_id': 'caseInstanceId',
        'process_definition_name': 'processDefinitionName',
        'process_definition_key': 'processDefinitionKey',
        'process_definition_version': 'processDefinitionVersion',
        'process_definition_id': 'processDefinitionId',
        'business_key': 'businessKey',
        'start_time': 'startTime',
        'end_time': 'endTime',
        'removal_time': 'removalTime',
        'duration_in_millis': 'durationInMillis',
        'start_user_id': 'startUserId',
        'start_activity_id': 'startActivityId',
        'delete_reason': 'deleteReason',
        'tenant_id': 'tenantId',
        'state': 'state'
    }

    def __init__(self, id=None, root_process_instance_id=None, super_process_instance_id=None, super_case_instance_id=None, case_instance_id=None, process_definition_name=None, process_definition_key=None, process_definition_version=None, process_definition_id=None, business_key=None, start_time=None, end_time=None, removal_time=None, duration_in_millis=None, start_user_id=None, start_activity_id=None, delete_reason=None, tenant_id=None, state=None, local_vars_configuration=None):  # noqa: E501
        """HistoricProcessInstanceDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._root_process_instance_id = None
        self._super_process_instance_id = None
        self._super_case_instance_id = None
        self._case_instance_id = None
        self._process_definition_name = None
        self._process_definition_key = None
        self._process_definition_version = None
        self._process_definition_id = None
        self._business_key = None
        self._start_time = None
        self._end_time = None
        self._removal_time = None
        self._duration_in_millis = None
        self._start_user_id = None
        self._start_activity_id = None
        self._delete_reason = None
        self._tenant_id = None
        self._state = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if root_process_instance_id is not None:
            self.root_process_instance_id = root_process_instance_id
        if super_process_instance_id is not None:
            self.super_process_instance_id = super_process_instance_id
        if super_case_instance_id is not None:
            self.super_case_instance_id = super_case_instance_id
        if case_instance_id is not None:
            self.case_instance_id = case_instance_id
        if process_definition_name is not None:
            self.process_definition_name = process_definition_name
        if process_definition_key is not None:
            self.process_definition_key = process_definition_key
        if process_definition_version is not None:
            self.process_definition_version = process_definition_version
        if process_definition_id is not None:
            self.process_definition_id = process_definition_id
        if business_key is not None:
            self.business_key = business_key
        self.start_time = start_time
        self.end_time = end_time
        self.removal_time = removal_time
        self.duration_in_millis = duration_in_millis
        if start_user_id is not None:
            self.start_user_id = start_user_id
        if start_activity_id is not None:
            self.start_activity_id = start_activity_id
        if delete_reason is not None:
            self.delete_reason = delete_reason
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if state is not None:
            self.state = state

    @property
    def id(self):
        """Gets the id of this HistoricProcessInstanceDto.  # noqa: E501

        The id of the process instance.  # noqa: E501

        :return: The id of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this HistoricProcessInstanceDto.

        The id of the process instance.  # noqa: E501

        :param id: The id of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def root_process_instance_id(self):
        """Gets the root_process_instance_id of this HistoricProcessInstanceDto.  # noqa: E501

        The process instance id of the root process instance that initiated the process.  # noqa: E501

        :return: The root_process_instance_id of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._root_process_instance_id

    @root_process_instance_id.setter
    def root_process_instance_id(self, root_process_instance_id):
        """Sets the root_process_instance_id of this HistoricProcessInstanceDto.

        The process instance id of the root process instance that initiated the process.  # noqa: E501

        :param root_process_instance_id: The root_process_instance_id of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._root_process_instance_id = root_process_instance_id

    @property
    def super_process_instance_id(self):
        """Gets the super_process_instance_id of this HistoricProcessInstanceDto.  # noqa: E501

        The id of the parent process instance, if it exists.  # noqa: E501

        :return: The super_process_instance_id of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._super_process_instance_id

    @super_process_instance_id.setter
    def super_process_instance_id(self, super_process_instance_id):
        """Sets the super_process_instance_id of this HistoricProcessInstanceDto.

        The id of the parent process instance, if it exists.  # noqa: E501

        :param super_process_instance_id: The super_process_instance_id of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._super_process_instance_id = super_process_instance_id

    @property
    def super_case_instance_id(self):
        """Gets the super_case_instance_id of this HistoricProcessInstanceDto.  # noqa: E501

        The id of the parent case instance, if it exists.  # noqa: E501

        :return: The super_case_instance_id of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._super_case_instance_id

    @super_case_instance_id.setter
    def super_case_instance_id(self, super_case_instance_id):
        """Sets the super_case_instance_id of this HistoricProcessInstanceDto.

        The id of the parent case instance, if it exists.  # noqa: E501

        :param super_case_instance_id: The super_case_instance_id of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._super_case_instance_id = super_case_instance_id

    @property
    def case_instance_id(self):
        """Gets the case_instance_id of this HistoricProcessInstanceDto.  # noqa: E501

        The id of the parent case instance, if it exists.  # noqa: E501

        :return: The case_instance_id of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._case_instance_id

    @case_instance_id.setter
    def case_instance_id(self, case_instance_id):
        """Sets the case_instance_id of this HistoricProcessInstanceDto.

        The id of the parent case instance, if it exists.  # noqa: E501

        :param case_instance_id: The case_instance_id of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._case_instance_id = case_instance_id

    @property
    def process_definition_name(self):
        """Gets the process_definition_name of this HistoricProcessInstanceDto.  # noqa: E501

        The name of the process definition that this process instance belongs to.  # noqa: E501

        :return: The process_definition_name of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_name

    @process_definition_name.setter
    def process_definition_name(self, process_definition_name):
        """Sets the process_definition_name of this HistoricProcessInstanceDto.

        The name of the process definition that this process instance belongs to.  # noqa: E501

        :param process_definition_name: The process_definition_name of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._process_definition_name = process_definition_name

    @property
    def process_definition_key(self):
        """Gets the process_definition_key of this HistoricProcessInstanceDto.  # noqa: E501

        The key of the process definition that this process instance belongs to.  # noqa: E501

        :return: The process_definition_key of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_key

    @process_definition_key.setter
    def process_definition_key(self, process_definition_key):
        """Sets the process_definition_key of this HistoricProcessInstanceDto.

        The key of the process definition that this process instance belongs to.  # noqa: E501

        :param process_definition_key: The process_definition_key of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._process_definition_key = process_definition_key

    @property
    def process_definition_version(self):
        """Gets the process_definition_version of this HistoricProcessInstanceDto.  # noqa: E501

        The version of the process definition that this process instance belongs to.  # noqa: E501

        :return: The process_definition_version of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: int
        """
        return self._process_definition_version

    @process_definition_version.setter
    def process_definition_version(self, process_definition_version):
        """Sets the process_definition_version of this HistoricProcessInstanceDto.

        The version of the process definition that this process instance belongs to.  # noqa: E501

        :param process_definition_version: The process_definition_version of this HistoricProcessInstanceDto.  # noqa: E501
        :type: int
        """

        self._process_definition_version = process_definition_version

    @property
    def process_definition_id(self):
        """Gets the process_definition_id of this HistoricProcessInstanceDto.  # noqa: E501

        The id of the process definition that this process instance belongs to.  # noqa: E501

        :return: The process_definition_id of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._process_definition_id

    @process_definition_id.setter
    def process_definition_id(self, process_definition_id):
        """Sets the process_definition_id of this HistoricProcessInstanceDto.

        The id of the process definition that this process instance belongs to.  # noqa: E501

        :param process_definition_id: The process_definition_id of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._process_definition_id = process_definition_id

    @property
    def business_key(self):
        """Gets the business_key of this HistoricProcessInstanceDto.  # noqa: E501

        The business key of the process instance.  # noqa: E501

        :return: The business_key of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._business_key

    @business_key.setter
    def business_key(self, business_key):
        """Sets the business_key of this HistoricProcessInstanceDto.

        The business key of the process instance.  # noqa: E501

        :param business_key: The business_key of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._business_key = business_key

    @property
    def start_time(self):
        """Gets the start_time of this HistoricProcessInstanceDto.  # noqa: E501

        The time the instance was started. Default [format](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/) `yyyy-MM-dd'T'HH:mm:ss.SSSZ`.  # noqa: E501

        :return: The start_time of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this HistoricProcessInstanceDto.

        The time the instance was started. Default [format](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/) `yyyy-MM-dd'T'HH:mm:ss.SSSZ`.  # noqa: E501

        :param start_time: The start_time of this HistoricProcessInstanceDto.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this HistoricProcessInstanceDto.  # noqa: E501

        The time the instance ended. Default [format](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/) `yyyy-MM-dd'T'HH:mm:ss.SSSZ`.  # noqa: E501

        :return: The end_time of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this HistoricProcessInstanceDto.

        The time the instance ended. Default [format](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/) `yyyy-MM-dd'T'HH:mm:ss.SSSZ`.  # noqa: E501

        :param end_time: The end_time of this HistoricProcessInstanceDto.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def removal_time(self):
        """Gets the removal_time of this HistoricProcessInstanceDto.  # noqa: E501

        The time after which the instance should be removed by the History Cleanup job. Default [format](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/) `yyyy-MM-dd'T'HH:mm:ss.SSSZ`.  # noqa: E501

        :return: The removal_time of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: datetime
        """
        return self._removal_time

    @removal_time.setter
    def removal_time(self, removal_time):
        """Sets the removal_time of this HistoricProcessInstanceDto.

        The time after which the instance should be removed by the History Cleanup job. Default [format](https://docs.camunda.org/manual/7.14/reference/rest/overview/date-format/) `yyyy-MM-dd'T'HH:mm:ss.SSSZ`.  # noqa: E501

        :param removal_time: The removal_time of this HistoricProcessInstanceDto.  # noqa: E501
        :type: datetime
        """

        self._removal_time = removal_time

    @property
    def duration_in_millis(self):
        """Gets the duration_in_millis of this HistoricProcessInstanceDto.  # noqa: E501

        The time the instance took to finish (in milliseconds).  # noqa: E501

        :return: The duration_in_millis of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: int
        """
        return self._duration_in_millis

    @duration_in_millis.setter
    def duration_in_millis(self, duration_in_millis):
        """Sets the duration_in_millis of this HistoricProcessInstanceDto.

        The time the instance took to finish (in milliseconds).  # noqa: E501

        :param duration_in_millis: The duration_in_millis of this HistoricProcessInstanceDto.  # noqa: E501
        :type: int
        """

        self._duration_in_millis = duration_in_millis

    @property
    def start_user_id(self):
        """Gets the start_user_id of this HistoricProcessInstanceDto.  # noqa: E501

        The id of the user who started the process instance.  # noqa: E501

        :return: The start_user_id of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._start_user_id

    @start_user_id.setter
    def start_user_id(self, start_user_id):
        """Sets the start_user_id of this HistoricProcessInstanceDto.

        The id of the user who started the process instance.  # noqa: E501

        :param start_user_id: The start_user_id of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._start_user_id = start_user_id

    @property
    def start_activity_id(self):
        """Gets the start_activity_id of this HistoricProcessInstanceDto.  # noqa: E501

        The id of the initial activity that was executed (e.g., a start event).  # noqa: E501

        :return: The start_activity_id of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._start_activity_id

    @start_activity_id.setter
    def start_activity_id(self, start_activity_id):
        """Sets the start_activity_id of this HistoricProcessInstanceDto.

        The id of the initial activity that was executed (e.g., a start event).  # noqa: E501

        :param start_activity_id: The start_activity_id of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._start_activity_id = start_activity_id

    @property
    def delete_reason(self):
        """Gets the delete_reason of this HistoricProcessInstanceDto.  # noqa: E501

        The provided delete reason in case the process instance was canceled during execution.  # noqa: E501

        :return: The delete_reason of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._delete_reason

    @delete_reason.setter
    def delete_reason(self, delete_reason):
        """Sets the delete_reason of this HistoricProcessInstanceDto.

        The provided delete reason in case the process instance was canceled during execution.  # noqa: E501

        :param delete_reason: The delete_reason of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._delete_reason = delete_reason

    @property
    def tenant_id(self):
        """Gets the tenant_id of this HistoricProcessInstanceDto.  # noqa: E501

        The tenant id of the process instance.  # noqa: E501

        :return: The tenant_id of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this HistoricProcessInstanceDto.

        The tenant id of the process instance.  # noqa: E501

        :param tenant_id: The tenant_id of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def state(self):
        """Gets the state of this HistoricProcessInstanceDto.  # noqa: E501

        Last state of the process instance, possible values are:  `ACTIVE` - running process instance  `SUSPENDED` - suspended process instances  `COMPLETED` - completed through normal end event  `EXTERNALLY_TERMINATED` - terminated externally, for instance through REST API  `INTERNALLY_TERMINATED` - terminated internally, for instance by terminating boundary event  # noqa: E501

        :return: The state of this HistoricProcessInstanceDto.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this HistoricProcessInstanceDto.

        Last state of the process instance, possible values are:  `ACTIVE` - running process instance  `SUSPENDED` - suspended process instances  `COMPLETED` - completed through normal end event  `EXTERNALLY_TERMINATED` - terminated externally, for instance through REST API  `INTERNALLY_TERMINATED` - terminated internally, for instance by terminating boundary event  # noqa: E501

        :param state: The state of this HistoricProcessInstanceDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["ACTIVE", "SUSPENDED", "COMPLETED", "EXTERNALLY_TERMINATED", "INTERNALLY_TERMINATED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoricProcessInstanceDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HistoricProcessInstanceDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class EventSubscriptionDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'event_type': 'str',
        'event_name': 'str',
        'execution_id': 'str',
        'process_instance_id': 'str',
        'activity_id': 'str',
        'created_date': 'datetime',
        'tenant_id': 'str'
    }

    attribute_map = {
        'id': 'id',
        'event_type': 'eventType',
        'event_name': 'eventName',
        'execution_id': 'executionId',
        'process_instance_id': 'processInstanceId',
        'activity_id': 'activityId',
        'created_date': 'createdDate',
        'tenant_id': 'tenantId'
    }

    def __init__(self, id=None, event_type=None, event_name=None, execution_id=None, process_instance_id=None, activity_id=None, created_date=None, tenant_id=None, local_vars_configuration=None):  # noqa: E501
        """EventSubscriptionDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._event_type = None
        self._event_name = None
        self._execution_id = None
        self._process_instance_id = None
        self._activity_id = None
        self._created_date = None
        self._tenant_id = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if event_type is not None:
            self.event_type = event_type
        if event_name is not None:
            self.event_name = event_name
        if execution_id is not None:
            self.execution_id = execution_id
        if process_instance_id is not None:
            self.process_instance_id = process_instance_id
        if activity_id is not None:
            self.activity_id = activity_id
        self.created_date = created_date
        if tenant_id is not None:
            self.tenant_id = tenant_id

    @property
    def id(self):
        """Gets the id of this EventSubscriptionDto.  # noqa: E501

        The id of the event subscription.  # noqa: E501

        :return: The id of this EventSubscriptionDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EventSubscriptionDto.

        The id of the event subscription.  # noqa: E501

        :param id: The id of this EventSubscriptionDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def event_type(self):
        """Gets the event_type of this EventSubscriptionDto.  # noqa: E501

        The type of the event subscription.  # noqa: E501

        :return: The event_type of this EventSubscriptionDto.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this EventSubscriptionDto.

        The type of the event subscription.  # noqa: E501

        :param event_type: The event_type of this EventSubscriptionDto.  # noqa: E501
        :type: str
        """

        self._event_type = event_type

    @property
    def event_name(self):
        """Gets the event_name of this EventSubscriptionDto.  # noqa: E501

        The name of the event this subscription belongs to as defined in the process model.  # noqa: E501

        :return: The event_name of this EventSubscriptionDto.  # noqa: E501
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this EventSubscriptionDto.

        The name of the event this subscription belongs to as defined in the process model.  # noqa: E501

        :param event_name: The event_name of this EventSubscriptionDto.  # noqa: E501
        :type: str
        """

        self._event_name = event_name

    @property
    def execution_id(self):
        """Gets the execution_id of this EventSubscriptionDto.  # noqa: E501

        The execution that is subscribed on the referenced event.  # noqa: E501

        :return: The execution_id of this EventSubscriptionDto.  # noqa: E501
        :rtype: str
        """
        return self._execution_id

    @execution_id.setter
    def execution_id(self, execution_id):
        """Sets the execution_id of this EventSubscriptionDto.

        The execution that is subscribed on the referenced event.  # noqa: E501

        :param execution_id: The execution_id of this EventSubscriptionDto.  # noqa: E501
        :type: str
        """

        self._execution_id = execution_id

    @property
    def process_instance_id(self):
        """Gets the process_instance_id of this EventSubscriptionDto.  # noqa: E501

        The process instance this subscription belongs to.  # noqa: E501

        :return: The process_instance_id of this EventSubscriptionDto.  # noqa: E501
        :rtype: str
        """
        return self._process_instance_id

    @process_instance_id.setter
    def process_instance_id(self, process_instance_id):
        """Sets the process_instance_id of this EventSubscriptionDto.

        The process instance this subscription belongs to.  # noqa: E501

        :param process_instance_id: The process_instance_id of this EventSubscriptionDto.  # noqa: E501
        :type: str
        """

        self._process_instance_id = process_instance_id

    @property
    def activity_id(self):
        """Gets the activity_id of this EventSubscriptionDto.  # noqa: E501

        The identifier of the activity that this event subscription belongs to. This could for example be the id of a receive task.  # noqa: E501

        :return: The activity_id of this EventSubscriptionDto.  # noqa: E501
        :rtype: str
        """
        return self._activity_id

    @activity_id.setter
    def activity_id(self, activity_id):
        """Sets the activity_id of this EventSubscriptionDto.

        The identifier of the activity that this event subscription belongs to. This could for example be the id of a receive task.  # noqa: E501

        :param activity_id: The activity_id of this EventSubscriptionDto.  # noqa: E501
        :type: str
        """

        self._activity_id = activity_id

    @property
    def created_date(self):
        """Gets the created_date of this EventSubscriptionDto.  # noqa: E501

        The time this event subscription was created.  # noqa: E501

        :return: The created_date of this EventSubscriptionDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this EventSubscriptionDto.

        The time this event subscription was created.  # noqa: E501

        :param created_date: The created_date of this EventSubscriptionDto.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    @property
    def tenant_id(self):
        """Gets the tenant_id of this EventSubscriptionDto.  # noqa: E501

        The id of the tenant this event subscription belongs to. Can be `null` if the subscription belongs to no single tenant.  # noqa: E501

        :return: The tenant_id of this EventSubscriptionDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this EventSubscriptionDto.

        The id of the tenant this event subscription belongs to. Can be `null` if the subscription belongs to no single tenant.  # noqa: E501

        :param tenant_id: The tenant_id of this EventSubscriptionDto.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventSubscriptionDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EventSubscriptionDto):
            return True

        return self.to_dict() != other.to_dict()
